from spell.api import base_client


ADMIN_RESOURCE_URL = "admin"
ORG_RESOURCE_URL = "orgs"


class AdminClient(base_client.BaseClient):

    def create_org(self, name, billing_email):
        """Create a new org at the server

        Keyword arguments:
        name -- name of the new org (must be at least 4 characters)
        billing_email -- billing_email of the new org

        """
        payload = {
            "name": name,
            "billing_email": billing_email,
        }
        r = self.request("post", ORG_RESOURCE_URL, payload=payload)
        self.check_and_raise(r)

    def create_cluster(self, cluster_name, org_name, external_id, role_arn,
                       security_group_id, storage_uri, bastion_key, vpc_id,
                       subnets, region):
        """Create a new cluster for an org

        Keyword arguments:
        cluster_name -- name of the new cluster
        org_name -- name of the org to add the cluster to
        external_id -- internally-generated id for external aws requests
        role_arn -- aws arn for role to assume
        security_group_id -- id of security group with custom IP rules
        storage_uri -- s3 uri for external spell resources
        bastion_key -- ssh private key for bastion access
        vpc_id -- aws id of vpc for worker machines
        subnets -- aws ids of subnets for worker machines
        region -- aws region for worker machines

        """
        payload = {
            "org_name": org_name,
            "cluster_name": cluster_name,
            "external_id": external_id,
            "role_arn": role_arn,
            "security_group_id": security_group_id,
            "storage_uri": storage_uri,
            "ssh_bastion_private_key": bastion_key,
            "vpc_id": vpc_id,
            "subnets": subnets,
            "region": region,
        }
        r = self.request("post", "{}/{}".format(ADMIN_RESOURCE_URL, "clusters"), payload=payload)
        self.check_and_raise(r)

    def update_cluster_bastion_key(self, cluster_id, new_key):
        """Update the SSH bastion private key for a cluster

        Keyword arguments:
        cluster_id -- internal id of the cluster
        new_key -- new ssh private key for bastion access
        """
        payload = {
            "ssh_bastion_private_key": new_key,
        }
        url = "{}/{}/{}/{}".format(ADMIN_RESOURCE_URL, "clusters", cluster_id, "sshd_key")
        r = self.request("put", url, payload=payload)
        self.check_and_raise(r)
